Use nextafter instead of nexttoward to avoid using long double calculation.

BUG=skia:
GOLD_TRYBOT_URL= https://gold.skia.org/search2?unt=true&query=source_type%3Dgm&master=false&issue=1621453004

Review URL: https://codereview.chromium.org/1621453004
diff --git a/src/core/SkScaleToSides.h b/src/core/SkScaleToSides.h
index c3fa172..81ce4c4 100644
--- a/src/core/SkScaleToSides.h
+++ b/src/core/SkScaleToSides.h
@@ -45,10 +45,10 @@
 
             // If newMaxRadius forces the total over the limit, then it needs to be
             // reduced by one ULP to be less than limit - newMinRadius.
             // Note: nexttowardf is a c99 call and should be std::nexttoward, but this is not
             // implemented in the ARM compiler.
             if (newMaxRadius + newMinRadius > limit) {
-                newMaxRadius = nexttowardf(newMaxRadius, 0.0);
+                newMaxRadius = nextafterf(newMaxRadius, 0.0f);
             }
             *maxRadius = newMaxRadius;
         }
@@ -45,10 +45,10 @@
             // If newMaxRadius forces the total over the limit, then it needs to be
             // reduced by one ULP to be less than limit - newMinRadius.
-            // Note: nexttowardf is a c99 call and should be std::nexttoward, but this is not
-            // implemented in the ARM compiler.
+            // Note: nextafterf is a c99 call and should be std::nextafter, but this is not
+            // implemented in the GCC ARM compiler.
             if (newMaxRadius + newMinRadius > limit) {